0.9.9 API documentation: matrix_transform.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

gtc/matrix_transform.hpp
Go to the documentation of this file.
1
21 #pragma once
22
23 // Dependencies
24 #include "../mat4x4.hpp"
25 #include "../vec2.hpp"
26 #include "../vec3.hpp"
27 #include "../vec4.hpp"
28 #include "../ext/matrix_projection.hpp"
29 #include "../ext/matrix_clip_space.hpp"
30 #include "../ext/matrix_transform.hpp"
31
32 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
33 # pragma message("GLM: GLM_GTC_matrix_transform extension included")
34 #endif
35
36 #include "matrix_transform.inl"